@@ -3,58 +3,39 @@ package Win32::Process::Kill;
 require Exporter;
 our @ISA = qw(Exporter);
 our @EXPORT = qw(Terminate Resume Suspend CreateRemoteThread DebugActiveProcess Kill GetHandle);
-our $VERSION = '2.68_01';
+our $VERSION = '2.642';
 require XSLoader;
 XSLoader::load('Win32::Process::Kill', $VERSION);
-use Carp qw' croak carp ';
 
-$::DEBUG = 0;
+sub GetHandle {map Win32::Process::Kill::_GetHandle($_),@_;}
 
-sub GetHandle { map Win32::Process::Kill::_GetHandle($_), @_ }
+sub Suspend {map Win32::Process::Kill::Suspend($_),@_;}
 
-sub Suspend { map Win32::Process::Kill::_Suspend($_), @_ }
+sub Resume {map Win32::Process::Kill::Resume($_),@_;}
 
-sub Resume { map Win32::Process::Kill::_Resume($_), @_ }
+sub Terminate {map Win32::Process::Kill::_TerminateProcess($_),@_;}
 
-sub Terminate { map Win32::Process::Kill::_TerminateProcess($_), @_ }
+sub CreateRemoteThread {map Win32::Process::Kill::_CreateRemoteThread($_),@_;}
 
-sub CreateRemoteThread { map Win32::Process::Kill::_CreateRemoteThread($_), @_}
-
-sub DebugActiveProcess { map Win32::Process::Kill::_DebugActiveProcess($_), @_ }
+sub DebugActiveProcess {map Win32::Process::Kill::_DebugActiveProcess($_),@_;}
 
 sub Kill {
-    # return a list so that users can know which process is killed successfully
-	map {
-
-		return 0 unless $_;
+	map{
 		my ($handle) = GetHandle($_);
-        my $ref = \$handle;
-        bless($ref, 'Win32::Process::Kill::Handle');
-        if ( ! Win32::Process::Kill::Suspend($handle)
-            && $::DEBUG > 0 ) {
-            carp "Failed to Suspend Process...\nBut still fine\n";
-        }
-
-		unless ( Win32::Process::Kill::_TerminateProcess($handle)
-		      || Win32::Process::Kill::_CreateRemoteThread($handle)
-		      || Win32::Process::Kill::_DebugActiveProcess($_) ) {
-            croak "Failed to terminate the process.\n" if $::DEBUG > 0;
-            return 0;
-        }
-		
-		Win32::Process::Kill::_Resume($_);
-
+		return 0 unless $_;
+		unless(Win32::Process::Kill::Suspend($handle)
+			|| Win32::Process::Kill::_TerminateProcess($handle)
+			|| Win32::Process::Kill::_CreateRemoteThread($handle)
+			|| Win32::Process::Kill::_DebugActiveProcess($_)){
+						return 0;
+		}
+		Win32::Process::Kill::Resume($_);
+		close $handle;
 		return 1;
-	} @_ ? @_ : $_;
-
+	}@_ ? @_ : $_;
 }
 
-package Win32::Process::Kill::Handle;
-sub DESTROY {
-    die "CloseHandle failed" if !_CloseHandle(${$_[0]}) && $::DEBUG > 0;
-}
-
-1;
+Win32::Process::Kill::Import();
 __END__
 
 =head1 NAME
@@ -145,8 +126,6 @@ or
 
 Baggio, Kwok Lok Chung. <rootkwok <AT> cpan <DOT> org>
 
-patches by Daniel Dragan <bulkdd <AT> cpan <DOT> org>
-
 =head1 COPYRIGHT AND LICENSE
 
 Copyright (C) 2009 by Baggio, Kwok Lok Chung
